﻿using System.Collections;
using System;
using UnityEngine;

/*
 * Cat Gun
 *  made by roff
 *  (my first people playground mod)
*/

namespace Mod
{
    public class Mod : MonoBehaviour
    {
        public static string ModTag = "roff";

        public static void Main()
        {
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("AK-47"),
                    NameOverride = "Cat Gun",
                    DescriptionOverride = "it's a gun.. but it's a cat..",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("assets/sprites/view.png"),

                    AfterSpawn = (Instance) =>
                    {
                        // define the variables
                        var catVariants = new Sprite[]
                        {
                            ModAPI.LoadSprite("assets/sprites/catvariants/cat01.png"),
                            ModAPI.LoadSprite("assets/sprites/catvariants/cat02.png"),
                            ModAPI.LoadSprite("assets/sprites/catvariants/cat03.png"),
                            ModAPI.LoadSprite("assets/sprites/catvariants/cat04.png"),
                            ModAPI.LoadSprite("assets/sprites/catvariants/cat05.png"),
                            ModAPI.LoadSprite("assets/sprites/catvariants/cat06.png")
                        };

                        var meowSounds = new AudioClip[]
                        {
                            ModAPI.LoadSound("assets/sfx/meow01.mp3"),
                            ModAPI.LoadSound("assets/sfx/meow02.mp3"),
                            ModAPI.LoadSound("assets/sfx/meow03.mp3"),
                            ModAPI.LoadSound("assets/sfx/meow04.mp3")
                        };

                        var fireSounds = new AudioClip[]
                        {
                            ModAPI.LoadSound("assets/sfx/fire01.wav"),
                            ModAPI.LoadSound("assets/sfx/fire02.wav"),
                            ModAPI.LoadSound("assets/sfx/fire03.wav"),
                            ModAPI.LoadSound("assets/sfx/fire04.wav"),
                            ModAPI.LoadSound("assets/sfx/fire05.wav"),
                            ModAPI.LoadSound("assets/sfx/fire06.wav"),
                            ModAPI.LoadSound("assets/sfx/fire07.wav"),
                            ModAPI.LoadSound("assets/sfx/fire08.wav")
                        };

                        // sprite
                        Instance.transform.localScale *= UnityEngine.Random.Range(.9f, 1.15f);
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("assets/sprites/hitbox.png", 10);
                        Instance.FixColliders();
                        Instance.GetComponent<SpriteRenderer>().sprite = catVariants[UnityEngine.Random.Range(0, catVariants.Length)];

                        // firearm behavior
                        var customCartridge = ModAPI.FindCartridge("7.62x39mm");
                        customCartridge.name = "cat BULLETS!!!";
                        customCartridge.Damage *= .15f;
                        customCartridge.StartSpeed *= 2f;
                        customCartridge.PenetrationRandomAngleMultiplier *= .5f;
                        customCartridge.Recoil *= .75f;
                        customCartridge.ImpactForce *= 1.5f;

                        var firearmBehavior = Instance.GetComponent<FirearmBehaviour>();
                        firearmBehavior.Cartridge = customCartridge;
                        firearmBehavior.FireDelay = 0f;
                        firearmBehavior.AutomaticFireInterval = .125f;

                        firearmBehavior.barrelPosition = new Vector2(.525f, .025f);
                        firearmBehavior.casingPosition = new Vector2(-.45f, 0f);
                        firearmBehavior.casingDirection = new Vector2(-3f, 0f);

                        firearmBehavior.ShotSounds = fireSounds;
                        firearmBehavior.ShotVolume = 4f;

                        // physical behavior
                        var physicalBehaviorProperties = ModAPI.FindPhysicalProperties("Human");
                        physicalBehaviorProperties.SoftImpact = meowSounds;
                        physicalBehaviorProperties.HardImpact = meowSounds;
                        physicalBehaviorProperties.Softness = 1f;
                        physicalBehaviorProperties.ImpactIntensityMutliplier *= 3f;
                        physicalBehaviorProperties.HitVolumeMultiplier = 1.5f;
                        physicalBehaviorProperties.SharpForceThresholdMultiplier *= .25f;

                        var physicalBehaviour = Instance.GetComponent<PhysicalBehaviour>();
                        physicalBehaviour.Properties = physicalBehaviorProperties;
                        physicalBehaviour.StabCausesWound = true;

                        // spawn meow :)
                        var meowSound = Instance.AddComponent<AudioSource>();
                        meowSound.volume = 2f;
                        meowSound.minDistance = 5f;
                        meowSound.maxDistance = 50f;
                        meowSound.spatialBlend = 0f;
                        meowSound.spread = 0f;
                        meowSound.clip = meowSounds[UnityEngine.Random.Range(0, meowSounds.Length)];
                        meowSound.Play();
                    }
                });
        }
    };
};